@@ -68,10 +68,9 @@ if ( $_GET['updated'] == 'true' ) {
 switch( $_GET['action'] ) {
 	// Edit blog
 	case "editblog":
-		switch_to_blog( $id );
 		$options = $wpdb->get_results( "SELECT * FROM {$wpdb->base_prefix}{$id}_options WHERE option_name NOT LIKE 'rss%' AND option_name NOT LIKE '%user_roles'", ARRAY_A );
 		$details = $wpdb->get_row( "SELECT * FROM {$wpdb->blogs} WHERE blog_id = '{$id}'", ARRAY_A );
-		$editblog_roles = get_option( "{$wpdb->base_prefix}{$id}_user_roles" );
+		$editblog_roles = get_blog_option( $id, "{$wpdb->base_prefix}{$id}_user_roles" );
 		?>
 		<div class="wrap">
 		<h2><?php _e('Edit Blog'); ?> - <a href='http://<?php echo $details['domain'].$details['path']; ?>'>http://<?php echo $details['domain'].$details['path']; ?></a></h2>
@@ -90,7 +89,7 @@ switch( $_GET['action'] ) {
 							<tr class="form-field form-required">
 								<th scope="row"><?php _e('Path') ?></th> 
 								<td><input name="blog[path]" type="text" id="path" value="<?php echo $details['path'] ?>" size="40" style='margin-bottom:5px;' />
-								<br /><input type='checkbox' style='width:20px;' name='update_home_url' value='update' <?php if( get_option( 'siteurl' ) == preg_replace('|/+$|', '', 'http://' . $details['domain'] . $details['path']) || get_option( 'home' ) == preg_replace('|/+$|', '', 'http://' . $details['domain'] . $details['path']) ) echo 'checked="checked"'; ?> /> <?php _e( "Update 'siteurl' and 'home' as well." ); ?></td>
+								<br /><input type='checkbox' style='width:20px;' name='update_home_url' value='update' <?php if( get_blog_option( $id, 'siteurl' ) == preg_replace('|/+$|', '', 'http://' . $details['domain'] . $details['path']) || get_blog_option( $id, 'home' ) == preg_replace('|/+$|', '', 'http://' . $details['domain'] . $details['path']) ) echo 'checked="checked"'; ?> /> <?php _e( "Update 'siteurl' and 'home' as well." ); ?></td>
 							</tr> 
 							<tr class="form-field">
 								<th scope="row"><?php _e('Registered') ?></th> 
@@ -260,7 +259,7 @@ switch( $_GET['action'] ) {
 			<div id="blogedit_blogadduser" class="postbox">
 			<h3 class='hndle'><span><?php _e('Add a new user'); ?></span></h3>
 			<div class="inside">
-				<p style="margin:10px 0 0px;padding:0px 10px 10px;border-bottom:1px solid #DFDFDF;"><?php _e('As you type WordPress will offer you a choice of usernames.<br /> Click them to select and hit <em>Update Options</em> to add the user.') ?></p>
+				<p style="margin:10px 0 0px;padding:0px 10px 10px;border-bottom:1px solid #DFDFDF;"><?php _e('Enter the username of an existing user and hit <em>Update Options</em> to add the user.') ?></p>
 				<table class="form-table">
 						<tr>
 							<th scope="row"><?php _e('User&nbsp;Login:') ?></th>
@@ -300,7 +299,6 @@ switch( $_GET['action'] ) {
 		</form>
 		</div>
 		<?php
-		restore_current_blog();
 	break;
 
 	// List blogs
@@ -575,6 +573,7 @@ switch( $_GET['action'] ) {
 		</div>
 
 		<div class="wrap">
+			<a name="form-add-blog"></a>
 			<h2><?php _e('Add Blog') ?></h2>
 			<form method="post" action="wpmu-edit.php?action=addblog">
 				<?php wp_nonce_field('add-blog') ?>
