@@ -200,8 +200,6 @@ switch( $_GET['action'] ) {
 			$c = 1;
 			$count = count( $_POST['option'] );
 			foreach ( (array) $_POST['option'] as $key => $val ) {
-				if ( $key == 0 )
-					continue;
 				$val = stripslashes_deep( $val );
 				if( $c == $count ) {
 					update_option( $key, $val );
